@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2015, 2020, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0, as
  * published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
- * documentation.  The authors of MySQL hereby grant you an
- * additional permission to link the program and your derivative works
- * with the separately licensed software that they have included with
- * MySQL.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation. The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  *
  * Without limiting anything contained in the foregoing, this file,
- * which is part of MySQL Connector/C++, is also subject to the
+ * which is part of Connector/C++, is also subject to the
  * Universal FOSS Exception, version 1.0, a copy of which can be found at
- * http://oss.oracle.com/licenses/universal-foss-exception.
+ * https://oss.oracle.com/licenses/universal-foss-exception.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,7 +25,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef MYSQLX_COMMON_SESSION_INT_H
@@ -44,6 +44,7 @@ PUSH_SYS_WARNINGS
 #include <list>
 #include <mutex>
 #include <condition_variable>
+#include <mutex>
 POP_SYS_WARNINGS
 
 namespace mysqlx {
@@ -62,11 +63,15 @@ using time_point = std::chrono::time_point<system_clock>;
 
 /*
   Abstract interface used to clean up a session before it is closed.
+  Also has methods to aquire lock and try_lock, so that Session pool can clean
+  on multi thread environment.
 */
 
 struct Session_cleanup
 {
   virtual void cleanup() = 0;
+  virtual std::unique_lock<std::recursive_mutex> lock() const = 0;
+  virtual std::unique_lock<std::recursive_mutex> try_lock() const = 0;
 };
 
 
@@ -300,6 +305,7 @@ public:
   std::set<uint32_t>  m_stmt_id;
   std::set<uint32_t>  m_stmt_id_cleanup;
   size_t              m_max_pstmt = std::numeric_limits<size_t>::max();
+  std::recursive_mutex m_mutex;
 
   Session_impl(Session_pool_shared &pool)
     : m_sess(pool, this)
@@ -454,10 +460,22 @@ public:
 
   void release();
 
+  /*
+    Implement Session_cleanup
+  */
   void cleanup() override
   {
     prepare_for_cmd();
   }
+  std::unique_lock<std::recursive_mutex> lock() const override {
+    return std::unique_lock<std::recursive_mutex>(
+        const_cast<Session_impl *>(this)->m_mutex);
+  }
+
+  std::unique_lock<std::recursive_mutex> try_lock() const override {
+    return std::unique_lock<std::recursive_mutex>(
+        const_cast<Session_impl *>(this)->m_mutex, std::try_to_lock);
+  }
 };
 
 
