@@ -1,22 +1,22 @@
 /*
- * Copyright (c) 2008, 2022, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0, as
  * published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
- * documentation.  The authors of MySQL hereby grant you an
- * additional permission to link the program and your derivative works
- * with the separately licensed software that they have included with
- * MySQL.
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation. The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
  *
  * Without limiting anything contained in the foregoing, this file,
- * which is part of MySQL Connector/C++, is also subject to the
+ * which is part of Connector/C++, is also subject to the
  * Universal FOSS Exception, version 1.0, a copy of which can be found at
- * http://oss.oracle.com/licenses/universal-foss-exception.
+ * https://oss.oracle.com/licenses/universal-foss-exception.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,7 +25,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 
@@ -1058,6 +1058,9 @@ MySQL_Prepared_ResultSet::getString(const uint32_t columnIndex) const
         case sql::DataType::ENUM:
         case sql::DataType::JSON:
         case sql::DataType::GEOMETRY:
+#ifdef HAVE_TYPE_VECTOR
+        case sql::DataType::VECTOR:
+#endif
             CPP_INFO("It's a string");
             return  sql::SQLString(static_cast<char *>(result_bind->rbind[columnIndex - 1].buffer), *result_bind->rbind[columnIndex - 1].length);
         default:
@@ -1084,6 +1087,55 @@ MySQL_Prepared_ResultSet::getString(const sql::SQLString& columnLabel) const
 /* }}} */
 
 
+/* {{{ MySQL_Prepared_ResultSet::getVector() -I- */
+std::vector<float> MySQL_Prepared_ResultSet::getVector(uint32_t columnIndex) const
+{
+    CPP_ENTER("MySQL_Prepared_ResultSet::getVector(int)");
+#if HAVE_TYPE_VECTOR
+    /* isBeforeFirst checks for validity */
+    if (isBeforeFirstOrAfterLast()) {
+        throw sql::InvalidArgumentException(
+            "MySQL_Prepared_ResultSet::getVector: can't fetch because not on result set");
+  }
+
+    if (columnIndex == 0 || columnIndex > num_fields) {
+        throw sql::InvalidArgumentException(
+            "MySQL_Prepared_ResultSet::getVector: invalid value of 'columnIndex'");
+    }
+
+    if (rs_meta->getColumnType(columnIndex) != sql::DataType::VECTOR) {
+        throw sql::InvalidArgumentException(
+            "MySQL_Prepared_ResultSet::getVector: invalid field type");
+    }
+
+    last_queried_column = columnIndex;
+    if (*result_bind->rbind[columnIndex - 1].is_null) {
+        return {};
+    }
+
+    // Get length in vector elements (float) instead of bytes
+    size_t len =
+        *result_bind->rbind[columnIndex - 1].length / sizeof(float);
+    float *data_buf =
+        static_cast<float *>(result_bind->rbind[columnIndex - 1].buffer);
+
+    return std::vector<float>(data_buf, data_buf + len);
+#else
+    throw sql::MethodNotImplementedException(
+        "MySQL_ResultSet::getVector()");
+#endif
+}
+
+
+/* {{{ MySQL_Prepared_ResultSet::getVector() -I- */
+std::vector<float> MySQL_Prepared_ResultSet::getVector(const sql::SQLString &columnLabel) const
+{
+    CPP_ENTER("MySQL_Prepared_ResultSet::getVector(string)");
+    return getVector(findColumn(columnLabel));
+}
+
+
+
 /* {{{ MySQL_Prepared_ResultSet::getType() -I- */
 sql::ResultSet::enum_type
 MySQL_Prepared_ResultSet::getType() const
