@@ -628,22 +628,6 @@ LibmysqlDynamicProxy::sqlstate(MYSQL * mysql)
 /* }}} */
 
 
-/* {{{ LibmysqlDynamicProxy::ssl_set() */
-my_bool
-LibmysqlDynamicProxy::ssl_set(MYSQL * mysql,
-                      const char * key,
-                      const char * cert,
-                      const char * ca,
-                      const char * capath,
-                      const char * cipher)
-{
-  static ptr2mysql_ssl_set ptr2_ssl_set = symbol_safe_cast<ptr2mysql_ssl_set>(GetProcAddr("mysql_ssl_set"));
-
-  return (*ptr2_ssl_set)(mysql, key, cert, ca, capath, cipher);
-}
-/* }}} */
-
-
 /* {{{ LibmysqlDynamicProxy::store_result() */
 MYSQL_RES *
 LibmysqlDynamicProxy::store_result(MYSQL * mysql)
@@ -700,12 +684,25 @@ LibmysqlDynamicProxy::stmt_attr_set(MYSQL_STMT * stmt, enum enum_stmt_attr_type
 }
 /* }}} */
 
+/* {{{ LibmysqlDynamicProxy::stmt_bind_named_param() */
+my_bool
+LibmysqlDynamicProxy::stmt_bind_named_param(MYSQL_STMT * stmt, MYSQL_BIND * bind,
+                                            unsigned n_params, const char **names)
+{
+  static ptr2mysql_stmt_bind_named_param ptr2_stmt_bind_named_param = symbol_safe_cast<ptr2mysql_stmt_bind_named_param>(GetProcAddr("mysql_stmt_bind_named_param"));
+  if (ptr2_stmt_bind_named_param == nullptr)
+    throw ::sql::MethodNotImplementedException("::mysql_stmt_bind_named_param()");
+
+    return (*ptr2_stmt_bind_named_param)(stmt, bind, n_params, names);
+}
 
 /* {{{ LibmysqlDynamicProxy::stmt_bind_param() */
 my_bool
 LibmysqlDynamicProxy::stmt_bind_param(MYSQL_STMT * stmt, MYSQL_BIND * bind)
 {
   static ptr2mysql_stmt_bind_param ptr2_stmt_bind_param = symbol_safe_cast<ptr2mysql_stmt_bind_param>(GetProcAddr("mysql_stmt_bind_param"));
+  if (ptr2_stmt_bind_param == nullptr)
+    throw ::sql::MethodNotImplementedException("::mysql_stmt_bind_param()");
 
   return (*ptr2_stmt_bind_param)(stmt, bind);
 }
